@@ -1,4 +1,6 @@
 from __future__ import unicode_literals
+from collections import OrderedDict
+
 from PyQt5.Qt import QPointF, QPoint, QObject
 
 import pqaut.automator.factory as factory
@@ -60,25 +62,26 @@ class QQuickItemAutomator(pqaut.automator.qobject.QObjectAutomator):
         return False
 
     def to_json(self, is_recursive = False):
-        json= { 'type':self._target.__class__.__name__, 
-                'automation_id': self.automation_id(),
-                'automation_type':self.automation_type(),
-                'name':self.get_name(), 
-                'value':self.get_value(),
-                'frame': { 
-                    'x':self.value_or_default('x', 0),
-                    'y':self.value_or_default('y', 0),
-                    'width':self.value_or_default('width', 0),
-                    'height':self.value_or_default('height', 0),
-                },
-                'global_position': {
-                    'x':self.global_position().x(),
-                    'y':self.global_position().y(),
-                },
-                'visible':self.value_or_default('visible', True),
-                'enabled':self.value_or_default('enabled', False),
-                'offscreen':self.is_offscreen(),
-                }
+        json=OrderedDict([
+                ('type',self._target.__class__.__name__), 
+                ('automation_id', self.automation_id()),
+                ('automation_type',self.automation_type()),
+                ('name',self.get_name()), 
+                ('value',self.get_value()),
+                ('visible',self.value_or_default('visible', True)),
+                ('enabled',self.value_or_default('enabled', False)),
+                ('offscreen',self.is_offscreen()),
+                ('frame', OrderedDict([ 
+                    ('x',self.value_or_default('x', 0)),
+                    ('y',self.value_or_default('y', 0)),
+                    ('width',self.value_or_default('width', 0)),
+                    ('height',self.value_or_default('height', 0)),
+                ])),
+                ('global_position', OrderedDict([
+                    ('x',self.global_position().x()),
+                    ('y',self.global_position().y()),
+                ])),
+            ])
 
         if is_recursive:
             children_json = []
